==> ulyxex.1.3.1.alone.zip: pages/core/admin_users.php <==
 <?php
/* Ulyxex version 1.3.1 *****************/
class Users extends Admin {
	public function __construct(){
		$this->h = New Html();
		$this->t = New Translate();
		$this->pagePos = isset($_GET['pg'])?$this->h->num($_GET['pg']):0;
		$this->Select =	SELECT."ID,LOGIN,USERLEVEL,USERNAME,USEROWNER ";
		$this->From = 	FROM.USERS;
		$this->SelectCount = SELECT."COUNT(ID) AS NUM ";
		$this->OrderSort = "";
		$this->Cond = array();
		$this->userPagesTotal = $this->sum_pages_by_users();
		$this->userArtsTotal = $this->sum_arts_by_users();
	}
	public function update_users(){
		$formValues = array();
		$values = $_POST;
		foreach($values as $k=>$v){
			if ( preg_match("/\_/",$k) ){
				list($key,$id) = explode("_",$k);
				$formValues[$id][$key] = $v;
			}
		}
		foreach($formValues as $id=>$value){
			$query = 0;
			if (isset($value['delete']) && $id != 1){ // nevers delete admin
				$query = DELETE.FROM.USERS.WHERE."ID = ".$id;
				$query = $this->q($query);
				// all user's articles, pages and link go to hide, sandbox and admin
				$query = UPDATE.ARTICLES.SET."HIDE = 1, PAGEID = 2, USERID = 1".WHERE."USERID = ".$id;
				$query = $this->q($query);
				$query = UPDATE.PAGES.SET."HIDE = 1, PARENTID = 2, USERID = 1".WHERE."USERID = ".$id;
				$query = $this->q($query);
				$query = UPDATE.LINKS.SET."HIDE = 1, USERID = 1".WHERE."USERID = ".$id;
				$query = $this->q($query);
				$query = UPDATE.USERS.SET."USEROWNER = 1".WHERE."USEROWNER = ".$id;
				$query = $this->q($query);
			}
			if ($value['oldname'] != $value['name']){
				$query = UPDATE.USERS.SET."USERNAME = '".$this->h->safe($value['name'])."'".WHERE."ID = ".$id;
				$query = $this->q($query);
			}
		}
		return $this->h->h3($this->t->w("some values have been modified !"),"class='warning'");
	}
	public function list_users(){
		$h = $this->h;$t = $this->t;
		$ownerName = array();
		$query = $this->q(SELECT."ID,USERNAME".FROM.USERS);
		while ( $line = $this->fetch($query) ){
			$ownerName[$line['ID']] = $line['USERNAME'];
		}
		$pgPos =($this->pagePos)?($this->pagePos - 1) * ADMINITEMSBYPAGE:0;
		if (isset($_GET['ownerFilter'])) $_SESSION['admin_users_filter'] = USERS.".USEROWNER = ".$h->num($_GET['ownerFilter']);
		if (isset($_POST['search_name'])) $_SESSION['admin_users_search_name'] = " MATCH(".USERS.".USERNAME) AGAINST('".$h->safe($_POST['search_name'])."') ";
		
		if (isset($_POST['reset'])){
			$_SESSION['admin_users_filter'] = "";
			$_SESSION['admin_users_search_name'] = "";
		}
		// 1) can create users etc.
		// 2) can create articles and pages
		// 3) can create articles everywhere
		// 4) can create articles only in sandbox
		
		$this->OrderSort = ORDERBY.USERS.".DATEPAGE DESC LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
		// user level 1 only edit his users
		$this->Cond = array();
		if ($_SESSION['userid'] != 1) $this->Cond[] = USERS.".USEROWNER = ".$_SESSION['userid'];
		if ( isset($_SESSION['admin_users_filter']) && !empty($_SESSION['admin_users_filter']) ) $this->Cond[] = $_SESSION['admin_users_filter'];
		if ( isset($_SESSION['admin_users_search_name']) && !empty($_SESSION['admin_users_search_name']) ) $this->Cond[] = $_SESSION['admin_users_search_name'];

		$query = $this->Select.$this->From.$this->Where($this->Cond).$this->OrderSort;
		$query = $this->q($query);
		
		$searchForm = $this->search_form("search_name","search by name","users");
		$goIdForm = $this->go_id("user","modify_user");
		$resetForm = $this->reset_form("users");
		
		$usersSubmit = $h->p($h->input("submit","",$t->w("update all")));
		$usersList = $h->h3($t->w("users list"));
		$usersList .= $h->input("hidden","update",1);
		
		while ( $line = $this->fetch($query) ){
			$id = $h->input("hidden","id",$line['ID'])."id ".$h->fmt($line['ID']);
		
			$pages = (isset($this->userPagesTotal[$line['ID']]))?$h->ahref("admin.php?action=pages&ownerFilter=".$line['ID'],$h->fmt($this->userPagesTotal[$line['ID']])):$h->fmt(0);
			$pages .= " pags";
			
			$arts = (isset($this->userArtsTotal[$line['ID']]))?$h->ahref("admin.php?action=articles&ownerFilter=".$line['ID'],$h->fmt($this->userArtsTotal[$line['ID']])):$h->fmt(0);
			$arts .= " arts";
			
			$modify = $h->ahref("admin.php?action=modify_user&amp;user=".$line['ID'],$t->w("modify"),"class='action'");
			
			$login = $h->strWidth($line['LOGIN'],12);
			
			$level = "^".$line['USERLEVEL'];
			
			$name = $t->wx("name").$h->input("text","name_".$line['ID'],$h->uly_htmlentities($line['USERNAME']),"size=19").
			$h->input("hidden","oldname_".$line['ID'],$h->uly_htmlentities($line['USERNAME']));
			
			$view = $h->ahref("index.php?k=user&amp;v=".$line['ID'],$t->w("view"),"class='action' target=_blank");
			
			$owner = ($_SESSION['userid'] == 1)?$t->wx("by").
						$h->ahref("admin.php?action=users&amp;ownerFilter=".$line['USEROWNER'],$h->strWidth($ownerName[$line['USEROWNER']],12),
						"class='action' title='".$h->uly_htmlentities($ownerName[$line['USEROWNER']])."'"):Null;
			
			$delete = ($line['ID'] != 1)?$t->wr("delete").$h->input("checkbox","delete_".$line['ID'],"on"):$h->span($t->wr("delete"),"style='text-decoration:line-through;color:red;'").
			$h->input("checkbox","none","none");
			
			$_ = array($this->bordered($id),$this->bordered($pages),$this->bordered($arts),$view,$modify,$this->bordered($delete),$this->bordered($login),$name,$this->bordered($level),$owner);
			$content = implode(" ",$_);
			$usersList .= $h->p($content);
		}
		$nextPages = $this->next_pages();
		$usersList = $usersSubmit.$usersList.$nextPages.$usersSubmit;
		return $searchForm.$goIdForm.$resetForm.$h->form($usersList,"users","post","admin.php?action=users&amp;pg=".$this->pagePos);
	}
	public function next_pages(){
		$query = $this->SelectCount.$this->From.$this->Where($this->Cond);
		$query = $this->q($query);
		$line = $this->fetch($query);
		$pagesNumbers = new NextPages($line['NUM'],"action=users");
		return $this->h->p($pagesNumbers->numbers());
	}
}
?>

==> ulyxex.1.3.2.alone.zip: pages/core/admin_users.php <==
 <?php
/* Ulyxex version 1.3.2 *****************/
class Users extends Admin {
	public function __construct(){
		$this->h = New Html();
		$this->t = New Translate();
		if (isset($_GET['pg'])) {
			$this->pagePos = $this->h->num($_GET['pg']);
			$_SESSION['pgu'] = $_GET['pg'];
		} elseif (isset($_SESSION['pgu']) && !empty($_SESSION['pgu']))  {
			$this->pagePos = $this->h->num($_SESSION['pgu']);
			$_GET['pg'] = $_SESSION['pgu'];
		} else {
			$this->pagePos = 0;
		}
		// $this->pagePos = isset($_GET['pg'])?$this->h->num($_GET['pg']):0;
		$this->Select =	SELECT."ID,LOGIN,USERLEVEL,USERNAME,USEROWNER ";
		$this->From = 	FROM.USERS;
		$this->SelectCount = SELECT."COUNT(ID) AS NUM ";
		$this->OrderSort = "";
		$this->Cond = array();
		$this->userPagesTotal = $this->sum_pages_by_users();
		$this->userArtsTotal = $this->sum_arts_by_users();
	}
	public function update_users(){
		$formValues = array();
		$values = $_POST;
		foreach($values as $k=>$v){
			if ( preg_match("/\_/",$k) ){
				list($key,$id) = explode("_",$k);
				$formValues[$id][$key] = $v;
			}
		}
		foreach($formValues as $id=>$value){
			$query = 0;
			if (isset($value['delete']) && $id != 1){ // nevers delete admin
				$query = DELETE.FROM.USERS.WHERE."ID = ".$id;
				$query = $this->q($query);
				// all user's articles, pages and link go to hide, sandbox and admin
				$query = UPDATE.ARTICLES.SET."HIDE = 1, PAGEID = 2, USERID = 1".WHERE."USERID = ".$id;
				$query = $this->q($query);
				$query = UPDATE.PAGES.SET."HIDE = 1, PARENTID = 2, USERID = 1".WHERE."USERID = ".$id;
				$query = $this->q($query);
				$query = UPDATE.LINKS.SET."HIDE = 1, USERID = 1".WHERE."USERID = ".$id;
				$query = $this->q($query);
				$query = UPDATE.USERS.SET."USEROWNER = 1".WHERE."USEROWNER = ".$id;
				$query = $this->q($query);
			}
			if ($value['oldname'] != $value['name']){
				$query = UPDATE.USERS.SET."USERNAME = '".$this->h->safe($value['name'])."'".WHERE."ID = ".$id;
				$query = $this->q($query);
			}
		}
		return $this->h->h3($this->t->w("some values have been modified !"),"class='warning'");
	}
	public function list_users(){
		$h = $this->h;$t = $this->t;
		$ownerName = array();
		$query = $this->q(SELECT."ID,USERNAME".FROM.USERS);
		while ( $line = $this->fetch($query) ){
			$ownerName[$line['ID']] = $line['USERNAME'];
		}
		$pgPos =($this->pagePos)?($this->pagePos - 1) * ADMINITEMSBYPAGE:0;
		if (isset($_GET['ownerFilter'])) $_SESSION['admin_users_filter'] = USERS.".USEROWNER = ".$h->num($_GET['ownerFilter']);
		if (isset($_POST['search_name'])) $_SESSION['admin_users_search_name'] = " MATCH(".USERS.".USERNAME) AGAINST('".$h->safe($_POST['search_name'])."') ";
		
		if (isset($_POST['reset'])){
			$_SESSION['admin_users_filter'] = "";
			$_SESSION['admin_users_search_name'] = "";
		}
		// 1) can create users etc.
		// 2) can create articles and pages
		// 3) can create articles everywhere
		// 4) can create articles only in sandbox
		
		$this->OrderSort = ORDERBY.USERS.".DATEPAGE DESC LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
		// user level 1 only edit his users
		$this->Cond = array();
		if ($_SESSION['userid'] != 1) $this->Cond[] = USERS.".USEROWNER = ".$_SESSION['userid'];
		if ( isset($_SESSION['admin_users_filter']) && !empty($_SESSION['admin_users_filter']) ) $this->Cond[] = $_SESSION['admin_users_filter'];
		if ( isset($_SESSION['admin_users_search_name']) && !empty($_SESSION['admin_users_search_name']) ) $this->Cond[] = $_SESSION['admin_users_search_name'];

		$query = $this->Select.$this->From.$this->Where($this->Cond).$this->OrderSort;
		$query = $this->q($query);
		
		$searchForm = $this->search_form("search_name","search by name","users");
		$goIdForm = $this->go_id("user","modify_user");
		$resetForm = $this->reset_form("users");
		
		$usersSubmit = $h->p($h->input("submit","",$t->w("update all")));
		$usersList = $h->h3($t->w("users list"));
		$usersList .= $h->input("hidden","update",1);
		
		while ( $line = $this->fetch($query) ){
			$id = $h->input("hidden","id",$line['ID'])."id ".$h->fmt($line['ID']);
		
			$pages = (isset($this->userPagesTotal[$line['ID']]))?$h->ahref("admin.php?action=pages&ownerFilter=".$line['ID'],$h->fmt($this->userPagesTotal[$line['ID']])):$h->fmt(0);
			$pages .= " pags";
			
			$arts = (isset($this->userArtsTotal[$line['ID']]))?$h->ahref("admin.php?action=articles&ownerFilter=".$line['ID'],$h->fmt($this->userArtsTotal[$line['ID']])):$h->fmt(0);
			$arts .= " arts";
			
			$modify = $h->ahref("admin.php?action=modify_user&amp;user=".$line['ID'],$t->w("modify"),"class='action'");
			
			$login = $h->strWidth($line['LOGIN'],12);
			
			$level = "^".$line['USERLEVEL'];
			
			$name = $t->wx("name").$h->input("text","name_".$line['ID'],$h->uly_htmlentities($line['USERNAME']),"size=19").
			$h->input("hidden","oldname_".$line['ID'],$h->uly_htmlentities($line['USERNAME']));
			
			$view = $h->ahref("index.php?k=user&amp;v=".$line['ID'],$t->w("view"),"class='action' target=_blank");
			
			$owner = ($_SESSION['userid'] == 1)?$t->wx("by").
						$h->ahref("admin.php?action=users&amp;ownerFilter=".$line['USEROWNER'],$h->strWidth($ownerName[$line['USEROWNER']],12),
						"class='action' title='".$h->uly_htmlentities($ownerName[$line['USEROWNER']])."'"):Null;
			
			$delete = ($line['ID'] != 1)?$t->wr("delete").$h->input("checkbox","delete_".$line['ID'],"on"):$h->span($t->wr("delete"),"style='text-decoration:line-through;color:red;'").
			$h->input("checkbox","none","none");
			
			$_ = array($this->bordered($id),$this->bordered($pages),$this->bordered($arts),$view,$modify,$this->bordered($delete),$this->bordered($login),$name,$this->bordered($level),$owner);
			$content = implode(" ",$_);
			$usersList .= $h->p($content);
		}
		$nextPages = $this->next_pages();
		$usersList = $usersSubmit.$usersList.$nextPages.$usersSubmit;
		return $searchForm.$goIdForm.$resetForm.$h->form($usersList,"users","post","admin.php?action=users&amp;pg=".$this->pagePos);
	}
	public function next_pages(){
		$query = $this->SelectCount.$this->From.$this->Where($this->Cond);
		$query = $this->q($query);
		$line = $this->fetch($query);
		$pagesNumbers = new NextPages($line['NUM'],"action=users");
		return $this->h->p($pagesNumbers->numbers());
	}
}
?>
